#[repr(C)]pub struct InstanceReadyResponse {}Trait Implementations
Sourceimpl Clone for InstanceReadyResponse
impl Clone for InstanceReadyResponse
Sourcefn clone(&self) -> InstanceReadyResponse
fn clone(&self) -> InstanceReadyResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InstanceReadyResponse
impl Debug for InstanceReadyResponse
Sourceimpl<'a, ___E> Encode<InstanceReadyResponse, ___E> for &'a InstanceReadyResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<InstanceReadyResponse, ___E> for &'a InstanceReadyResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<InstanceReadyResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<InstanceReadyResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<InstanceReadyResponse, ___E> for InstanceReadyResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<InstanceReadyResponse, ___E> for InstanceReadyResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<InstanceReadyResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<InstanceReadyResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, InstanceReadyResponse>, ___E> for &'a InstanceReadyResponse
impl<'a, ___E> EncodeOption<Box<'static, InstanceReadyResponse>, ___E> for &'a InstanceReadyResponse
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, InstanceReadyResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, InstanceReadyResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, InstanceReadyResponse>, ___E> for InstanceReadyResponse
impl<___E> EncodeOption<Box<'static, InstanceReadyResponse>, ___E> for InstanceReadyResponse
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, InstanceReadyResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, InstanceReadyResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<InstanceReadyResponse> for InstanceReadyResponse
impl FromWire<InstanceReadyResponse> for InstanceReadyResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<InstanceReadyResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<InstanceReadyResponse, Self>
Sourcefn from_wire(wire: InstanceReadyResponse) -> Self
fn from_wire(wire: InstanceReadyResponse) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<InstanceReadyResponse> for InstanceReadyResponse
impl FromWireRef<InstanceReadyResponse> for InstanceReadyResponse
Sourcefn from_wire_ref(wire: &InstanceReadyResponse) -> Self
fn from_wire_ref(wire: &InstanceReadyResponse) -> Self
Converts the given reference to this type.
Sourceimpl Hash for InstanceReadyResponse
impl Hash for InstanceReadyResponse
Sourceimpl Ord for InstanceReadyResponse
impl Ord for InstanceReadyResponse
Sourcefn cmp(&self, other: &InstanceReadyResponse) -> Ordering
fn cmp(&self, other: &InstanceReadyResponse) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for InstanceReadyResponse
impl PartialEq for InstanceReadyResponse
Sourceimpl PartialOrd for InstanceReadyResponse
impl PartialOrd for InstanceReadyResponse
impl Copy for InstanceReadyResponse
impl Eq for InstanceReadyResponse
impl StructuralPartialEq for InstanceReadyResponse