#[repr(C)]pub struct Point {
pub x: i64,
pub y: i64,
}Expand description
A point in 2D space.
Fields
x: i64y: i64Trait Implementations
Sourceimpl CompatFrom<Point> for Point
impl CompatFrom<Point> for Point
Sourcefn compat_from(value: Point) -> Self
fn compat_from(value: Point) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<Point> for Point
impl CompatFrom<Point> for Point
Sourcefn compat_from(value: Point) -> Self
fn compat_from(value: Point) -> Self
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<Point, ___E> for &'a Pointwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Point, ___E> for &'a Pointwhere
___E: InternalHandleEncoder + ?Sized,
Sourceimpl<___E> Encode<Point, ___E> for Pointwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Point, ___E> for Pointwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, Point>
const COPY_OPTIMIZATION: CopyOptimization<Self, Point>
Sourceimpl<'a, ___E> EncodeOption<Box<'static, Point>, ___E> for &'a Point
impl<'a, ___E> EncodeOption<Box<'static, Point>, ___E> for &'a Point
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Point>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Point>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, Point>, ___E> for Point
impl<___E> EncodeOption<Box<'static, Point>, ___E> for Point
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Point>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Point>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWireRef<Point> for Point
impl FromWireRef<Point> for Point
Sourcefn from_wire_ref(wire: &Point) -> Self
fn from_wire_ref(wire: &Point) -> Self
Converts the given reference to this type.
Sourceimpl Ord for Point
impl Ord for Point
Sourceimpl PartialOrd for Point
impl PartialOrd for Point
impl Copy for Point
impl Eq for Point
impl StructuralPartialEq for Point